.. _dataformats_spectra:

Spectra
=======

The term ``spectrum`` is used for many different things by different people...

Flux points
-----------

* ``ENERGY``, ``ENERGY_LO``, ``ENERGY_HI`` with arbitrary units
* ``FLUX``, ``FLUX_ERR_LO``, ``FLUX_ERR_HI`` with arbitrary units

Counts, effective area, energy resolution
-----------------------------------------

Use OGIP (TODO: links) ``xspec`` data formats:

* Counts data: PHA files
* Effective area: ARF files
* Energy resolution: RMF files

